@@ -1,5 +1,5 @@
 /* tiger.c  -  The TIGER hash function
- *	Copyright (C) 1998 Free Software Foundation, Inc.
+ *	Copyright (C) 1998, 1999, 2000, 2001 Free Software Foundation, Inc.
  *
  * This file is part of GnuPG.
  *
@@ -23,9 +23,9 @@
 #include <stdlib.h>
 #include <string.h>
 #include <assert.h>
-#include "g10lib.h"
+#include "util.h"
 #include "memory.h"
-
+#include "algorithms.h"
 
 #ifdef HAVE_U64_TYPEDEF
 
@@ -630,6 +630,19 @@ print_data( const char *text, u64 a, u64 b, u64 c,
 }
 
 
+static void
+burn_stack (int bytes)
+{
+    char buf[256];
+    
+    memset (buf, 0, sizeof buf);
+    bytes -= sizeof buf;
+    if (bytes > 0)
+        burn_stack (bytes);
+}
+
+
+
 static void
 tiger_init( TIGER_CONTEXT *hd )
 {
@@ -768,6 +781,7 @@ tiger_write( TIGER_CONTEXT *hd, byte *inbuf, size_t inlen)
 {
     if( hd->count == 64 ) { /* flush the buffer */
 	transform( hd, hd->buf );
+        burn_stack (21*8+11*sizeof(void*));
 	hd->count = 0;
 	hd->nblocks++;
     }
@@ -788,6 +802,7 @@ tiger_write( TIGER_CONTEXT *hd, byte *inbuf, size_t inlen)
 	inlen -= 64;
 	inbuf += 64;
     }
+    burn_stack (21*8+11*sizeof(void*));
     for( ; inlen && hd->count < 64; inlen-- )
 	hd->buf[hd->count++] = *inbuf++;
 }
@@ -805,18 +820,19 @@ tiger_final( TIGER_CONTEXT *hd )
 
     tiger_write(hd, NULL, 0); /* flush */;
 
-    msb = 0;
     t = hd->nblocks;
-    if( (lsb = t << 6) < t ) /* multiply by 64 to make a byte count */
-	msb++;
-    msb += t >> 26;
+    /* multiply by 64 to make a byte count */
+    lsb = t << 6;
+    msb = t >> 26;
+    /* add the count */
     t = lsb;
-    if( (lsb = t + hd->count) < t ) /* add the count */
+    if( (lsb += hd->count) < t )
 	msb++;
+    /* multiply by 8 to make a bit count */
     t = lsb;
-    if( (lsb = t << 3) < t ) /* multiply by 8 to make a bit count */
-	msb++;
-    msb += t >> 29;
+    lsb <<= 3;
+    msb <<= 3;
+    msb |= t >> 29;
 
     if( hd->count < 56 ) { /* enough room */
 	hd->buf[hd->count++] = 0x01; /* pad */
@@ -840,15 +856,16 @@ tiger_final( TIGER_CONTEXT *hd )
     hd->buf[62] = msb >> 16;
     hd->buf[63] = msb >> 24;
     transform( hd, hd->buf );
+    burn_stack (21*8+11*sizeof(void*));
 
     p = hd->buf;
   #ifdef BIG_ENDIAN_HOST
-    #define X(a) do { *(u64*)p = hd->##a ; p += 8; } while(0)
+    #define X(a) do { *(u64*)p = hd-> a ; p += 8; } while(0)
   #else /* little endian */
-    #define X(a) do { *p++ = hd->##a >> 56; *p++ = hd->##a >> 48; \
-		      *p++ = hd->##a >> 40; *p++ = hd->##a >> 32; \
-		      *p++ = hd->##a >> 24; *p++ = hd->##a >> 16; \
-		      *p++ = hd->##a >>  8; *p++ = hd->##a; } while(0)
+    #define X(a) do { *p++ = hd-> a >> 56; *p++ = hd-> a >> 48; \
+		      *p++ = hd-> a >> 40; *p++ = hd-> a >> 32; \
+		      *p++ = hd-> a >> 24; *p++ = hd-> a >> 16; \
+		      *p++ = hd-> a >>  8; *p++ = hd-> a; } while(0)
   #endif
     X(a);
     X(b);
@@ -862,13 +879,15 @@ tiger_read( TIGER_CONTEXT *hd )
     return hd->buf;
 }
 
+#endif /*HAVE_U64_TYPEDEF*/
+
 /****************
  * Return some information about the algorithm.  We need algo here to
  * distinguish different flavors of the algorithm.
  * Returns: A pointer to string describing the algorithm or NULL if
  *	    the ALGO is invalid.
  */
-static const char *
+const char *
 tiger_get_info( int algo, size_t *contextsize,
 	       byte **r_asnoid, int *r_asnlen, int *r_mdlen,
 	       void (**r_init)( void *c ),
@@ -877,6 +896,7 @@ tiger_get_info( int algo, size_t *contextsize,
 	       byte *(**r_read)( void *c )
 	     )
 {
+#ifdef HAVE_U64_TYPEDEF
     /* 40: SEQUENCE {
      * 12:   SEQUENCE {
      *	8:     OCTET STRING   :54 49 47 45 52 31 39 32
@@ -887,6 +907,7 @@ tiger_get_info( int algo, size_t *contextsize,
      *
      * By replacing the 5th byte (0x04) with 0x16 we would have;
      *	      8:     IA5String 'TIGER192'
+     * Fixme: We should use a registered OID.
      */
     static byte asn[18] =
 		{ 0x30, 0x28, 0x30, 0x0c, 0x04, 0x08, 0x54, 0x49, 0x47,
@@ -904,88 +925,8 @@ tiger_get_info( int algo, size_t *contextsize,
     *(void  (**)(TIGER_CONTEXT *))r_final		 = tiger_final;
     *(byte *(**)(TIGER_CONTEXT *))r_read		 = tiger_read;
 
-    return "TIGER";
-}
-
-
-
-#ifndef IS_MODULE
-static
+    return "TIGER192";
+#else /*!HAVE_U64_TYPEDEF*/
+    return NULL; /* Alorithm not available. */
 #endif
-const char * const gnupgext_version = "TIGER ($Revision: 1.12 $)";
-
-static struct {
-    int class;
-    int version;
-    int  value;
-    void (*func)(void);
-} func_table[] = {
-    { 10, 1, 0, (void(*)(void))tiger_get_info },
-    { 11, 1, 6 },
-};
-
-
-
-/****************
- * Enumerate the names of the functions together with informations about
- * this function. Set sequence to an integer with a initial value of 0 and
- * do not change it.
- * If what is 0 all kind of functions are returned.
- * Return values: class := class of function:
- *			   10 = message digest algorithm info function
- *			   11 = integer with available md algorithms
- *			   20 = cipher algorithm info function
- *			   21 = integer with available cipher algorithms
- *			   30 = public key algorithm info function
- *			   31 = integer with available pubkey algorithms
- *		  version = interface version of the function/pointer
- *			    (currently this is 1 for all functions)
- */
-#ifndef IS_MODULE
-static
-#endif
-void *
-gnupgext_enum_func( int what, int *sequence, int *class, int *vers )
-{
-    void *ret;
-    int i = *sequence;
-
-    do {
-	if( i >= DIM(func_table) || i < 0 ) {
-	    /*fprintf(stderr, "failed\n");*/
-	    return NULL;
-	}
-	*class = func_table[i].class;
-	*vers  = func_table[i].version;
-	switch( *class ) {
-	  case 11:
-	  case 21:
-	  case 31:
-	    ret = &func_table[i].value;
-	    break;
-	  default:
-	    ret = func_table[i].func;
-	    break;
-	}
-	i++;
-    } while( what && what != *class );
-
-    *sequence = i;
-    /*fprintf(stderr, "success\n");*/
-    return ret;
 }
-
-
-
-#ifndef IS_MODULE
-void
-tiger_constructor(void)
-{
-    register_internal_cipher_extension( gnupgext_version,
-					gnupgext_enum_func );
-}
-#endif
-
-
-#endif /* HAVE_U64_TYPEDEF */
-
